package com.shzg.project.worn.service;

import java.util.List;
import com.shzg.project.worn.domain.WornInboundItem;
import com.shzg.project.worn.domain.dto.WornInboundUpdateDTO;

/**
 * 入库单明细Service接口
 * 
 * @author shzg
 * @date 2026-03-26
 */
public interface IWornInboundItemService 
{
    /**
     * 查询入库单明细
     * 
     * @param id 入库单明细主键
     * @return 入库单明细
     */
    public WornInboundItem selectWornInboundItemById(Long id);

    /**
     * 查询入库单明细列表
     * 
     * @param wornInboundItem 入库单明细
     * @return 入库单明细集合
     */
    public WornInboundUpdateDTO selectWornInboundItemByBillNo(WornInboundItem wornInboundItem);

    /**
     * 新增入库单明细
     * 
     * @param wornInboundItem 入库单明细
     * @return 结果
     */
    public int insertWornInboundItem(WornInboundItem wornInboundItem);

    /**
     * 修改入库单明细
     * 
     * @param dto 入库单明细
     * @return 结果
     */
    public int updateWornInboundItem(WornInboundUpdateDTO dto);

    /**
     * 批量删除入库单明细
     * 
     * @param ids 需要删除的入库单明细主键集合
     * @return 结果
     */
    public int deleteWornInboundItemByIds(Long[] ids);

    /**
     * 删除入库单明细信息
     * 
     * @param id 入库单明细主键
     * @return 结果
     */
    public int deleteWornInboundItemById(Long id);
}
