package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.github.pagehelper.PageHelper;
import com.shzg.project.worn.domain.dto.WornInboundUpdateDTO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.WornInboundItem;
import com.shzg.project.worn.service.IWornInboundItemService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 入库单明细Controller
 * 
 * @author shzg
 * @date 2026-03-26
 */
@RestController
@RequestMapping("/worn/item")
public class WornInboundItemController extends BaseController
{
    @Autowired
    private IWornInboundItemService wornInboundItemService;

    /**
     * 查询入库单明细列表
     */
    @PreAuthorize("@ss.hasPermi('worn:item:list')")
    @GetMapping("/list")
    public AjaxResult  list(WornInboundItem wornInboundItem)
    {
        //startPage();
        WornInboundUpdateDTO list = wornInboundItemService.selectWornInboundItemByBillNo(wornInboundItem);
        return AjaxResult.success(list);
    }

//    /**
//     * 导出入库单明细列表
//     */
//    @PreAuthorize("@ss.hasPermi('worn:item:export')")
//    @Log(title = "入库单明细", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, WornInboundItem wornInboundItem)
//    {
//        List<WornInboundItem> list = wornInboundItemService.selectWornInboundItemByBillNo(wornInboundItem);
//        ExcelUtil<WornInboundItem> util = new ExcelUtil<WornInboundItem>(WornInboundItem.class);
//        util.exportExcel(response, list, "入库单明细数据");
//    }

    /**
     * 获取入库单明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:item:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wornInboundItemService.selectWornInboundItemById(id));
    }

    /**
     * 新增入库单明细
     */
    @PreAuthorize("@ss.hasPermi('worn:item:add')")
    @Log(title = "入库单明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WornInboundItem wornInboundItem)
    {
        return toAjax(wornInboundItemService.insertWornInboundItem(wornInboundItem));
    }

    /**
     * 修改入库单明细
     */
    @PreAuthorize("@ss.hasPermi('worn:item:edit')")
    @Log(title = "入库单明细", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    public AjaxResult edit(@RequestBody WornInboundUpdateDTO dto)
    {
        return toAjax(wornInboundItemService.updateWornInboundItem(dto));
    }

    /**
     * 删除入库单明细
     */
    @PreAuthorize("@ss.hasPermi('worn:item:remove')")
    @Log(title = "入库单明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wornInboundItemService.deleteWornInboundItemByIds(ids));
    }
}
